<p align="center">
  <img src="https://raw.githubusercontent.com/nnilayy/kernl/main/assets/kernl-banner.png" alt="Kernl Banner" width="80%">
</p>

<p align="center">
  <a href="https://pypi.org/project/kernl/">
    <img src="https://img.shields.io/pypi/v/kernl.svg?color=brightgreen" alt="PyPI Version">
  </a>
  <a href="https://pepy.tech/project/kernl">
    <img src="https://static.pepy.tech/badge/kernl" alt="Downloads">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/kernl.svg" alt="Python Versions">
  <a href="https://github.com/nnilayy/kernl/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/nnilayy/kernl.svg" alt="License">
  </a>
</p>
